# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayCreateK8SAuthConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_id': 'str',
        'cluster_api_type': 'str',
        'config_encryption_key_name': 'str',
        'disable_issuer_validation': 'str',
        'json': 'bool',
        'k8s_ca_cert': 'str',
        'k8s_host': 'str',
        'k8s_issuer': 'str',
        'name': 'str',
        'rancher_api_key': 'str',
        'rancher_cluster_id': 'str',
        'signing_key': 'str',
        'token': 'str',
        'token_exp': 'int',
        'token_reviewer_jwt': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'access_id': 'access-id',
        'cluster_api_type': 'cluster-api-type',
        'config_encryption_key_name': 'config-encryption-key-name',
        'disable_issuer_validation': 'disable-issuer-validation',
        'json': 'json',
        'k8s_ca_cert': 'k8s-ca-cert',
        'k8s_host': 'k8s-host',
        'k8s_issuer': 'k8s-issuer',
        'name': 'name',
        'rancher_api_key': 'rancher-api-key',
        'rancher_cluster_id': 'rancher-cluster-id',
        'signing_key': 'signing-key',
        'token': 'token',
        'token_exp': 'token-exp',
        'token_reviewer_jwt': 'token-reviewer-jwt',
        'uid_token': 'uid-token'
    }

    def __init__(self, access_id=None, cluster_api_type='native_k8s', config_encryption_key_name=None, disable_issuer_validation=None, json=None, k8s_ca_cert=None, k8s_host=None, k8s_issuer=None, name=None, rancher_api_key=None, rancher_cluster_id=None, signing_key=None, token=None, token_exp=300, token_reviewer_jwt=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """GatewayCreateK8SAuthConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_id = None
        self._cluster_api_type = None
        self._config_encryption_key_name = None
        self._disable_issuer_validation = None
        self._json = None
        self._k8s_ca_cert = None
        self._k8s_host = None
        self._k8s_issuer = None
        self._name = None
        self._rancher_api_key = None
        self._rancher_cluster_id = None
        self._signing_key = None
        self._token = None
        self._token_exp = None
        self._token_reviewer_jwt = None
        self._uid_token = None
        self.discriminator = None

        self.access_id = access_id
        if cluster_api_type is not None:
            self.cluster_api_type = cluster_api_type
        if config_encryption_key_name is not None:
            self.config_encryption_key_name = config_encryption_key_name
        if disable_issuer_validation is not None:
            self.disable_issuer_validation = disable_issuer_validation
        if json is not None:
            self.json = json
        if k8s_ca_cert is not None:
            self.k8s_ca_cert = k8s_ca_cert
        self.k8s_host = k8s_host
        if k8s_issuer is not None:
            self.k8s_issuer = k8s_issuer
        self.name = name
        if rancher_api_key is not None:
            self.rancher_api_key = rancher_api_key
        if rancher_cluster_id is not None:
            self.rancher_cluster_id = rancher_cluster_id
        self.signing_key = signing_key
        if token is not None:
            self.token = token
        if token_exp is not None:
            self.token_exp = token_exp
        if token_reviewer_jwt is not None:
            self.token_reviewer_jwt = token_reviewer_jwt
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def access_id(self):
        """Gets the access_id of this GatewayCreateK8SAuthConfig.  # noqa: E501

        The access ID of the Kubernetes auth method  # noqa: E501

        :return: The access_id of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._access_id

    @access_id.setter
    def access_id(self, access_id):
        """Sets the access_id of this GatewayCreateK8SAuthConfig.

        The access ID of the Kubernetes auth method  # noqa: E501

        :param access_id: The access_id of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and access_id is None:  # noqa: E501
            raise ValueError("Invalid value for `access_id`, must not be `None`")  # noqa: E501

        self._access_id = access_id

    @property
    def cluster_api_type(self):
        """Gets the cluster_api_type of this GatewayCreateK8SAuthConfig.  # noqa: E501

        Cluster access type. options: [native_k8s, rancher]  # noqa: E501

        :return: The cluster_api_type of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._cluster_api_type

    @cluster_api_type.setter
    def cluster_api_type(self, cluster_api_type):
        """Sets the cluster_api_type of this GatewayCreateK8SAuthConfig.

        Cluster access type. options: [native_k8s, rancher]  # noqa: E501

        :param cluster_api_type: The cluster_api_type of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """

        self._cluster_api_type = cluster_api_type

    @property
    def config_encryption_key_name(self):
        """Gets the config_encryption_key_name of this GatewayCreateK8SAuthConfig.  # noqa: E501

        Config encryption key  # noqa: E501

        :return: The config_encryption_key_name of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._config_encryption_key_name

    @config_encryption_key_name.setter
    def config_encryption_key_name(self, config_encryption_key_name):
        """Sets the config_encryption_key_name of this GatewayCreateK8SAuthConfig.

        Config encryption key  # noqa: E501

        :param config_encryption_key_name: The config_encryption_key_name of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """

        self._config_encryption_key_name = config_encryption_key_name

    @property
    def disable_issuer_validation(self):
        """Gets the disable_issuer_validation of this GatewayCreateK8SAuthConfig.  # noqa: E501

        Disable issuer validation  # noqa: E501

        :return: The disable_issuer_validation of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._disable_issuer_validation

    @disable_issuer_validation.setter
    def disable_issuer_validation(self, disable_issuer_validation):
        """Sets the disable_issuer_validation of this GatewayCreateK8SAuthConfig.

        Disable issuer validation  # noqa: E501

        :param disable_issuer_validation: The disable_issuer_validation of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """

        self._disable_issuer_validation = disable_issuer_validation

    @property
    def json(self):
        """Gets the json of this GatewayCreateK8SAuthConfig.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayCreateK8SAuthConfig.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def k8s_ca_cert(self):
        """Gets the k8s_ca_cert of this GatewayCreateK8SAuthConfig.  # noqa: E501

        The CA Certificate (base64 encoded) to use to call into the kubernetes API server  # noqa: E501

        :return: The k8s_ca_cert of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._k8s_ca_cert

    @k8s_ca_cert.setter
    def k8s_ca_cert(self, k8s_ca_cert):
        """Sets the k8s_ca_cert of this GatewayCreateK8SAuthConfig.

        The CA Certificate (base64 encoded) to use to call into the kubernetes API server  # noqa: E501

        :param k8s_ca_cert: The k8s_ca_cert of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """

        self._k8s_ca_cert = k8s_ca_cert

    @property
    def k8s_host(self):
        """Gets the k8s_host of this GatewayCreateK8SAuthConfig.  # noqa: E501

        The URL of the kubernetes API server  # noqa: E501

        :return: The k8s_host of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._k8s_host

    @k8s_host.setter
    def k8s_host(self, k8s_host):
        """Sets the k8s_host of this GatewayCreateK8SAuthConfig.

        The URL of the kubernetes API server  # noqa: E501

        :param k8s_host: The k8s_host of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and k8s_host is None:  # noqa: E501
            raise ValueError("Invalid value for `k8s_host`, must not be `None`")  # noqa: E501

        self._k8s_host = k8s_host

    @property
    def k8s_issuer(self):
        """Gets the k8s_issuer of this GatewayCreateK8SAuthConfig.  # noqa: E501

        The Kubernetes JWT issuer name. If not set, kubernetes/serviceaccount will use as an issuer.  # noqa: E501

        :return: The k8s_issuer of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._k8s_issuer

    @k8s_issuer.setter
    def k8s_issuer(self, k8s_issuer):
        """Sets the k8s_issuer of this GatewayCreateK8SAuthConfig.

        The Kubernetes JWT issuer name. If not set, kubernetes/serviceaccount will use as an issuer.  # noqa: E501

        :param k8s_issuer: The k8s_issuer of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """

        self._k8s_issuer = k8s_issuer

    @property
    def name(self):
        """Gets the name of this GatewayCreateK8SAuthConfig.  # noqa: E501

        K8S Auth config name  # noqa: E501

        :return: The name of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayCreateK8SAuthConfig.

        K8S Auth config name  # noqa: E501

        :param name: The name of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def rancher_api_key(self):
        """Gets the rancher_api_key of this GatewayCreateK8SAuthConfig.  # noqa: E501

        The api key used to access the TokenReview API to validate other JWTs (relevant for \"rancher\" only)  # noqa: E501

        :return: The rancher_api_key of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._rancher_api_key

    @rancher_api_key.setter
    def rancher_api_key(self, rancher_api_key):
        """Sets the rancher_api_key of this GatewayCreateK8SAuthConfig.

        The api key used to access the TokenReview API to validate other JWTs (relevant for \"rancher\" only)  # noqa: E501

        :param rancher_api_key: The rancher_api_key of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """

        self._rancher_api_key = rancher_api_key

    @property
    def rancher_cluster_id(self):
        """Gets the rancher_cluster_id of this GatewayCreateK8SAuthConfig.  # noqa: E501

        The cluster id as define in rancher (relevant for \"rancher\" only)  # noqa: E501

        :return: The rancher_cluster_id of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._rancher_cluster_id

    @rancher_cluster_id.setter
    def rancher_cluster_id(self, rancher_cluster_id):
        """Sets the rancher_cluster_id of this GatewayCreateK8SAuthConfig.

        The cluster id as define in rancher (relevant for \"rancher\" only)  # noqa: E501

        :param rancher_cluster_id: The rancher_cluster_id of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """

        self._rancher_cluster_id = rancher_cluster_id

    @property
    def signing_key(self):
        """Gets the signing_key of this GatewayCreateK8SAuthConfig.  # noqa: E501

        The private key (base64 encoded) associated with the public key defined in the Kubernetes auth  # noqa: E501

        :return: The signing_key of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._signing_key

    @signing_key.setter
    def signing_key(self, signing_key):
        """Sets the signing_key of this GatewayCreateK8SAuthConfig.

        The private key (base64 encoded) associated with the public key defined in the Kubernetes auth  # noqa: E501

        :param signing_key: The signing_key of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and signing_key is None:  # noqa: E501
            raise ValueError("Invalid value for `signing_key`, must not be `None`")  # noqa: E501

        self._signing_key = signing_key

    @property
    def token(self):
        """Gets the token of this GatewayCreateK8SAuthConfig.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayCreateK8SAuthConfig.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def token_exp(self):
        """Gets the token_exp of this GatewayCreateK8SAuthConfig.  # noqa: E501

        Time in seconds of expiration of the Akeyless Kube Auth Method token  # noqa: E501

        :return: The token_exp of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: int
        """
        return self._token_exp

    @token_exp.setter
    def token_exp(self, token_exp):
        """Sets the token_exp of this GatewayCreateK8SAuthConfig.

        Time in seconds of expiration of the Akeyless Kube Auth Method token  # noqa: E501

        :param token_exp: The token_exp of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: int
        """

        self._token_exp = token_exp

    @property
    def token_reviewer_jwt(self):
        """Gets the token_reviewer_jwt of this GatewayCreateK8SAuthConfig.  # noqa: E501

        A Kubernetes service account JWT used to access the TokenReview API to validate other JWTs (relevant for \"native_k8s\" only). If not set, the JWT submitted in the authentication process will be used to access the Kubernetes TokenReview API.  # noqa: E501

        :return: The token_reviewer_jwt of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._token_reviewer_jwt

    @token_reviewer_jwt.setter
    def token_reviewer_jwt(self, token_reviewer_jwt):
        """Sets the token_reviewer_jwt of this GatewayCreateK8SAuthConfig.

        A Kubernetes service account JWT used to access the TokenReview API to validate other JWTs (relevant for \"native_k8s\" only). If not set, the JWT submitted in the authentication process will be used to access the Kubernetes TokenReview API.  # noqa: E501

        :param token_reviewer_jwt: The token_reviewer_jwt of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """

        self._token_reviewer_jwt = token_reviewer_jwt

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayCreateK8SAuthConfig.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayCreateK8SAuthConfig.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayCreateK8SAuthConfig.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayCreateK8SAuthConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayCreateK8SAuthConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.akeyless_gateway_config import AkeylessGatewayConfig  # noqa: E501
from akeyless.rest import ApiException

class TestAkeylessGatewayConfig(unittest.TestCase):
    """AkeylessGatewayConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AkeylessGatewayConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.akeyless_gateway_config.AkeylessGatewayConfig()  # noqa: E501
        if include_optional :
            return AkeylessGatewayConfig(
                admins = akeyless.models.admins_config_part.AdminsConfigPart(
                    admins = [
                        '0'
                        ], ), 
                cache = akeyless.models.cache_config_part.CacheConfigPart(
                    cache_enable = True, 
                    cache_ttl = '0', 
                    proactive_cache_dump_interval = '0', 
                    proactive_cache_enable = True, 
                    proactive_cache_minimum_fetching_time = '0', ), 
                cf = akeyless.models.cf_config_part.CFConfigPart(
                    customer_fragements = {
                        'key' : '0'
                        }, ), 
                config_protection_key_name = '0', 
                general = akeyless.models.general_config_part.GeneralConfigPart(
                    akeyless_url = '0', 
                    api_token_ttl = '0', 
                    enable_tls = True, 
                    enable_tls_configure = True, 
                    enable_tls_curl = True, 
                    enable_tls_hvp = True, 
                    tcp_port = '0', 
                    tls_cert = '0', 
                    tls_key = '0', ), 
                ldap = akeyless.models.ldap_config_part.LdapConfigPart(
                    ldap_access_id = '0', 
                    ldap_anonymous_search = True, 
                    ldap_bind_dn = '0', 
                    ldap_bind_password = '0', 
                    ldap_cert = '0', 
                    ldap_enable = True, 
                    ldap_group_attr = '0', 
                    ldap_group_dn = '0', 
                    ldap_group_filter = '0', 
                    ldap_private_key = '0', 
                    ldap_token_expiration = '0', 
                    ldap_url = '0', 
                    ldap_user_attr = '0', 
                    ldap_user_dn = '0', ), 
                leadership = akeyless.models.leadership_config_part.LeadershipConfigPart(
                    open_leadership = [
                        56
                        ], ), 
                log_forwarding = akeyless.models.log_forwarding_config_part.LogForwardingConfigPart(
                    elasticsearch_config = akeyless.models.elasticsearch_log_forwarding_config.ElasticsearchLogForwardingConfig(
                        elasticsearch_host = '0', 
                        elasticsearch_index = '0', 
                        elasticsearch_nodes = '0', ), 
                    logan_enable = True, 
                    logan_url = '0', 
                    logstash_config = akeyless.models.logstash_log_forwarding_config.LogstashLogForwardingConfig(
                        logstash_dns = '0', 
                        logstash_protocol = '0', ), 
                    logz_io_config = akeyless.models.logz_io_log_forwarding_config.LogzIoLogForwardingConfig(
                        target_logz_io_protocol = '0', 
                        target_logz_io_token = '0', ), 
                    pull_interval_sec = '0', 
                    splunk_config = akeyless.models.splunk_log_forwarding_config.SplunkLogForwardingConfig(
                        splunk_index = '0', 
                        splunk_source = '0', 
                        splunk_sourcetype = '0', 
                        splunk_token = '0', 
                        splunk_url = '0', ), 
                    syslog_config = akeyless.models.syslog_log_forwarding_config.SyslogLogForwardingConfig(
                        syslog_host = '0', 
                        syslog_network = '0', 
                        syslog_target_tag = '0', ), 
                    target_log_type = '0', ), 
                migrations = akeyless.models.migrations_config_part.MigrationsConfigPart(
                    aws_secrets_migrations = [
                        akeyless.models.aws_secrets_migration.AWSSecretsMigration(
                            general = akeyless.models.migration_general.MigrationGeneral(
                                id = '0', 
                                name = '0', 
                                prefix = '0', 
                                protection_key = '0', ), 
                            payload = akeyless.models.aws_payload.AWSPayload(
                                key = '0', 
                                region = '0', 
                                secret = '0', ), )
                        ], 
                    azure_kv_migrations = [
                        akeyless.models.azure_key_vault_migration.AzureKeyVaultMigration()
                        ], 
                    hashi_migrations = [
                        akeyless.models.hashi_migration.HashiMigration()
                        ], 
                    k8s_migrations = [
                        akeyless.models.k8_s_migration.K8SMigration()
                        ], ), 
                producers = akeyless.models.producers_config_part.ProducersConfigPart(
                    producers = [
                        akeyless.models.producer.Producer(
                            active = True, 
                            id = 56, 
                            name = '0', 
                            type = '0', )
                        ], ), 
                saml = akeyless.models.saml_config_part.SamlConfigPart(
                    open_id_connect_access_id = '0', 
                    saml_access_id = '0', ), 
                uidentity = akeyless.models.u_identity_config_part.UIdentityConfigPart(
                    uid_access_id = '0', 
                    uid_enable = True, 
                    uid_rotate_interval = '0', 
                    uid_status = '0', 
                    uid_token = '0', ), 
                version = 56
            )
        else :
            return AkeylessGatewayConfig(
        )

    def testAkeylessGatewayConfig(self):
        """Test AkeylessGatewayConfig"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class MigrationsConfigPart(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'active_directory_migrations': 'list[ActiveDirectoryMigration]',
        'aws_secrets_migrations': 'list[AWSSecretsMigration]',
        'azure_kv_migrations': 'list[AzureKeyVaultMigration]',
        'gcp_secrets_migrations': 'list[GCPSecretsMigration]',
        'hashi_migrations': 'list[HashiMigration]',
        'k8s_migrations': 'list[K8SMigration]',
        'mock_migrations': 'list[MockMigration]',
        'one_password_migrations': 'list[OnePasswordMigration]'
    }

    attribute_map = {
        'active_directory_migrations': 'active_directory_migrations',
        'aws_secrets_migrations': 'aws_secrets_migrations',
        'azure_kv_migrations': 'azure_kv_migrations',
        'gcp_secrets_migrations': 'gcp_secrets_migrations',
        'hashi_migrations': 'hashi_migrations',
        'k8s_migrations': 'k8s_migrations',
        'mock_migrations': 'mock_migrations',
        'one_password_migrations': 'one_password_migrations'
    }

    def __init__(self, active_directory_migrations=None, aws_secrets_migrations=None, azure_kv_migrations=None, gcp_secrets_migrations=None, hashi_migrations=None, k8s_migrations=None, mock_migrations=None, one_password_migrations=None, local_vars_configuration=None):  # noqa: E501
        """MigrationsConfigPart - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._active_directory_migrations = None
        self._aws_secrets_migrations = None
        self._azure_kv_migrations = None
        self._gcp_secrets_migrations = None
        self._hashi_migrations = None
        self._k8s_migrations = None
        self._mock_migrations = None
        self._one_password_migrations = None
        self.discriminator = None

        if active_directory_migrations is not None:
            self.active_directory_migrations = active_directory_migrations
        if aws_secrets_migrations is not None:
            self.aws_secrets_migrations = aws_secrets_migrations
        if azure_kv_migrations is not None:
            self.azure_kv_migrations = azure_kv_migrations
        if gcp_secrets_migrations is not None:
            self.gcp_secrets_migrations = gcp_secrets_migrations
        if hashi_migrations is not None:
            self.hashi_migrations = hashi_migrations
        if k8s_migrations is not None:
            self.k8s_migrations = k8s_migrations
        if mock_migrations is not None:
            self.mock_migrations = mock_migrations
        if one_password_migrations is not None:
            self.one_password_migrations = one_password_migrations

    @property
    def active_directory_migrations(self):
        """Gets the active_directory_migrations of this MigrationsConfigPart.  # noqa: E501


        :return: The active_directory_migrations of this MigrationsConfigPart.  # noqa: E501
        :rtype: list[ActiveDirectoryMigration]
        """
        return self._active_directory_migrations

    @active_directory_migrations.setter
    def active_directory_migrations(self, active_directory_migrations):
        """Sets the active_directory_migrations of this MigrationsConfigPart.


        :param active_directory_migrations: The active_directory_migrations of this MigrationsConfigPart.  # noqa: E501
        :type: list[ActiveDirectoryMigration]
        """

        self._active_directory_migrations = active_directory_migrations

    @property
    def aws_secrets_migrations(self):
        """Gets the aws_secrets_migrations of this MigrationsConfigPart.  # noqa: E501


        :return: The aws_secrets_migrations of this MigrationsConfigPart.  # noqa: E501
        :rtype: list[AWSSecretsMigration]
        """
        return self._aws_secrets_migrations

    @aws_secrets_migrations.setter
    def aws_secrets_migrations(self, aws_secrets_migrations):
        """Sets the aws_secrets_migrations of this MigrationsConfigPart.


        :param aws_secrets_migrations: The aws_secrets_migrations of this MigrationsConfigPart.  # noqa: E501
        :type: list[AWSSecretsMigration]
        """

        self._aws_secrets_migrations = aws_secrets_migrations

    @property
    def azure_kv_migrations(self):
        """Gets the azure_kv_migrations of this MigrationsConfigPart.  # noqa: E501


        :return: The azure_kv_migrations of this MigrationsConfigPart.  # noqa: E501
        :rtype: list[AzureKeyVaultMigration]
        """
        return self._azure_kv_migrations

    @azure_kv_migrations.setter
    def azure_kv_migrations(self, azure_kv_migrations):
        """Sets the azure_kv_migrations of this MigrationsConfigPart.


        :param azure_kv_migrations: The azure_kv_migrations of this MigrationsConfigPart.  # noqa: E501
        :type: list[AzureKeyVaultMigration]
        """

        self._azure_kv_migrations = azure_kv_migrations

    @property
    def gcp_secrets_migrations(self):
        """Gets the gcp_secrets_migrations of this MigrationsConfigPart.  # noqa: E501


        :return: The gcp_secrets_migrations of this MigrationsConfigPart.  # noqa: E501
        :rtype: list[GCPSecretsMigration]
        """
        return self._gcp_secrets_migrations

    @gcp_secrets_migrations.setter
    def gcp_secrets_migrations(self, gcp_secrets_migrations):
        """Sets the gcp_secrets_migrations of this MigrationsConfigPart.


        :param gcp_secrets_migrations: The gcp_secrets_migrations of this MigrationsConfigPart.  # noqa: E501
        :type: list[GCPSecretsMigration]
        """

        self._gcp_secrets_migrations = gcp_secrets_migrations

    @property
    def hashi_migrations(self):
        """Gets the hashi_migrations of this MigrationsConfigPart.  # noqa: E501


        :return: The hashi_migrations of this MigrationsConfigPart.  # noqa: E501
        :rtype: list[HashiMigration]
        """
        return self._hashi_migrations

    @hashi_migrations.setter
    def hashi_migrations(self, hashi_migrations):
        """Sets the hashi_migrations of this MigrationsConfigPart.


        :param hashi_migrations: The hashi_migrations of this MigrationsConfigPart.  # noqa: E501
        :type: list[HashiMigration]
        """

        self._hashi_migrations = hashi_migrations

    @property
    def k8s_migrations(self):
        """Gets the k8s_migrations of this MigrationsConfigPart.  # noqa: E501


        :return: The k8s_migrations of this MigrationsConfigPart.  # noqa: E501
        :rtype: list[K8SMigration]
        """
        return self._k8s_migrations

    @k8s_migrations.setter
    def k8s_migrations(self, k8s_migrations):
        """Sets the k8s_migrations of this MigrationsConfigPart.


        :param k8s_migrations: The k8s_migrations of this MigrationsConfigPart.  # noqa: E501
        :type: list[K8SMigration]
        """

        self._k8s_migrations = k8s_migrations

    @property
    def mock_migrations(self):
        """Gets the mock_migrations of this MigrationsConfigPart.  # noqa: E501


        :return: The mock_migrations of this MigrationsConfigPart.  # noqa: E501
        :rtype: list[MockMigration]
        """
        return self._mock_migrations

    @mock_migrations.setter
    def mock_migrations(self, mock_migrations):
        """Sets the mock_migrations of this MigrationsConfigPart.


        :param mock_migrations: The mock_migrations of this MigrationsConfigPart.  # noqa: E501
        :type: list[MockMigration]
        """

        self._mock_migrations = mock_migrations

    @property
    def one_password_migrations(self):
        """Gets the one_password_migrations of this MigrationsConfigPart.  # noqa: E501


        :return: The one_password_migrations of this MigrationsConfigPart.  # noqa: E501
        :rtype: list[OnePasswordMigration]
        """
        return self._one_password_migrations

    @one_password_migrations.setter
    def one_password_migrations(self, one_password_migrations):
        """Sets the one_password_migrations of this MigrationsConfigPart.


        :param one_password_migrations: The one_password_migrations of this MigrationsConfigPart.  # noqa: E501
        :type: list[OnePasswordMigration]
        """

        self._one_password_migrations = one_password_migrations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MigrationsConfigPart):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MigrationsConfigPart):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class AuthMethodAccessInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_expires': 'int',
        'access_id_alias': 'str',
        'api_key_access_rules': 'APIKeyAccessRules',
        'aws_iam_access_rules': 'AWSIAMAccessRules',
        'azure_ad_access_rules': 'AzureADAccessRules',
        'cert_access_rules': 'CertAccessRules',
        'cidr_whitelist': 'str',
        'email_pass_access_rules': 'EmailPassAccessRules',
        'force_sub_claims': 'bool',
        'gcp_access_rules': 'GCPAccessRules',
        'gw_cidr_whitelist': 'str',
        'huawei_access_rules': 'HuaweiAccessRules',
        'jwt_ttl': 'int',
        'k8s_access_rules': 'KubernetesAccessRules',
        'ldap_access_rules': 'LDAPAccessRules',
        'oauth2_access_rules': 'OAuth2AccessRules',
        'oidc_access_rules': 'OIDCAccessRules',
        'rules_type': 'str',
        'saml_access_rules': 'SAMLAccessRules',
        'universal_identity_access_rules': 'UniversalIdentityAccessRules'
    }

    attribute_map = {
        'access_expires': 'access_expires',
        'access_id_alias': 'access_id_alias',
        'api_key_access_rules': 'api_key_access_rules',
        'aws_iam_access_rules': 'aws_iam_access_rules',
        'azure_ad_access_rules': 'azure_ad_access_rules',
        'cert_access_rules': 'cert_access_rules',
        'cidr_whitelist': 'cidr_whitelist',
        'email_pass_access_rules': 'email_pass_access_rules',
        'force_sub_claims': 'force_sub_claims',
        'gcp_access_rules': 'gcp_access_rules',
        'gw_cidr_whitelist': 'gw_cidr_whitelist',
        'huawei_access_rules': 'huawei_access_rules',
        'jwt_ttl': 'jwt_ttl',
        'k8s_access_rules': 'k8s_access_rules',
        'ldap_access_rules': 'ldap_access_rules',
        'oauth2_access_rules': 'oauth2_access_rules',
        'oidc_access_rules': 'oidc_access_rules',
        'rules_type': 'rules_type',
        'saml_access_rules': 'saml_access_rules',
        'universal_identity_access_rules': 'universal_identity_access_rules'
    }

    def __init__(self, access_expires=None, access_id_alias=None, api_key_access_rules=None, aws_iam_access_rules=None, azure_ad_access_rules=None, cert_access_rules=None, cidr_whitelist=None, email_pass_access_rules=None, force_sub_claims=None, gcp_access_rules=None, gw_cidr_whitelist=None, huawei_access_rules=None, jwt_ttl=None, k8s_access_rules=None, ldap_access_rules=None, oauth2_access_rules=None, oidc_access_rules=None, rules_type=None, saml_access_rules=None, universal_identity_access_rules=None, local_vars_configuration=None):  # noqa: E501
        """AuthMethodAccessInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_expires = None
        self._access_id_alias = None
        self._api_key_access_rules = None
        self._aws_iam_access_rules = None
        self._azure_ad_access_rules = None
        self._cert_access_rules = None
        self._cidr_whitelist = None
        self._email_pass_access_rules = None
        self._force_sub_claims = None
        self._gcp_access_rules = None
        self._gw_cidr_whitelist = None
        self._huawei_access_rules = None
        self._jwt_ttl = None
        self._k8s_access_rules = None
        self._ldap_access_rules = None
        self._oauth2_access_rules = None
        self._oidc_access_rules = None
        self._rules_type = None
        self._saml_access_rules = None
        self._universal_identity_access_rules = None
        self.discriminator = None

        if access_expires is not None:
            self.access_expires = access_expires
        if access_id_alias is not None:
            self.access_id_alias = access_id_alias
        if api_key_access_rules is not None:
            self.api_key_access_rules = api_key_access_rules
        if aws_iam_access_rules is not None:
            self.aws_iam_access_rules = aws_iam_access_rules
        if azure_ad_access_rules is not None:
            self.azure_ad_access_rules = azure_ad_access_rules
        if cert_access_rules is not None:
            self.cert_access_rules = cert_access_rules
        if cidr_whitelist is not None:
            self.cidr_whitelist = cidr_whitelist
        if email_pass_access_rules is not None:
            self.email_pass_access_rules = email_pass_access_rules
        if force_sub_claims is not None:
            self.force_sub_claims = force_sub_claims
        if gcp_access_rules is not None:
            self.gcp_access_rules = gcp_access_rules
        if gw_cidr_whitelist is not None:
            self.gw_cidr_whitelist = gw_cidr_whitelist
        if huawei_access_rules is not None:
            self.huawei_access_rules = huawei_access_rules
        if jwt_ttl is not None:
            self.jwt_ttl = jwt_ttl
        if k8s_access_rules is not None:
            self.k8s_access_rules = k8s_access_rules
        if ldap_access_rules is not None:
            self.ldap_access_rules = ldap_access_rules
        if oauth2_access_rules is not None:
            self.oauth2_access_rules = oauth2_access_rules
        if oidc_access_rules is not None:
            self.oidc_access_rules = oidc_access_rules
        if rules_type is not None:
            self.rules_type = rules_type
        if saml_access_rules is not None:
            self.saml_access_rules = saml_access_rules
        if universal_identity_access_rules is not None:
            self.universal_identity_access_rules = universal_identity_access_rules

    @property
    def access_expires(self):
        """Gets the access_expires of this AuthMethodAccessInfo.  # noqa: E501


        :return: The access_expires of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: int
        """
        return self._access_expires

    @access_expires.setter
    def access_expires(self, access_expires):
        """Sets the access_expires of this AuthMethodAccessInfo.


        :param access_expires: The access_expires of this AuthMethodAccessInfo.  # noqa: E501
        :type: int
        """

        self._access_expires = access_expires

    @property
    def access_id_alias(self):
        """Gets the access_id_alias of this AuthMethodAccessInfo.  # noqa: E501

        for accounts where AccessId holds encrypted email this field will hold generated AccessId, for accounts based on regular AccessId it will be equal to accessId itself  # noqa: E501

        :return: The access_id_alias of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: str
        """
        return self._access_id_alias

    @access_id_alias.setter
    def access_id_alias(self, access_id_alias):
        """Sets the access_id_alias of this AuthMethodAccessInfo.

        for accounts where AccessId holds encrypted email this field will hold generated AccessId, for accounts based on regular AccessId it will be equal to accessId itself  # noqa: E501

        :param access_id_alias: The access_id_alias of this AuthMethodAccessInfo.  # noqa: E501
        :type: str
        """

        self._access_id_alias = access_id_alias

    @property
    def api_key_access_rules(self):
        """Gets the api_key_access_rules of this AuthMethodAccessInfo.  # noqa: E501


        :return: The api_key_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: APIKeyAccessRules
        """
        return self._api_key_access_rules

    @api_key_access_rules.setter
    def api_key_access_rules(self, api_key_access_rules):
        """Sets the api_key_access_rules of this AuthMethodAccessInfo.


        :param api_key_access_rules: The api_key_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :type: APIKeyAccessRules
        """

        self._api_key_access_rules = api_key_access_rules

    @property
    def aws_iam_access_rules(self):
        """Gets the aws_iam_access_rules of this AuthMethodAccessInfo.  # noqa: E501


        :return: The aws_iam_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: AWSIAMAccessRules
        """
        return self._aws_iam_access_rules

    @aws_iam_access_rules.setter
    def aws_iam_access_rules(self, aws_iam_access_rules):
        """Sets the aws_iam_access_rules of this AuthMethodAccessInfo.


        :param aws_iam_access_rules: The aws_iam_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :type: AWSIAMAccessRules
        """

        self._aws_iam_access_rules = aws_iam_access_rules

    @property
    def azure_ad_access_rules(self):
        """Gets the azure_ad_access_rules of this AuthMethodAccessInfo.  # noqa: E501


        :return: The azure_ad_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: AzureADAccessRules
        """
        return self._azure_ad_access_rules

    @azure_ad_access_rules.setter
    def azure_ad_access_rules(self, azure_ad_access_rules):
        """Sets the azure_ad_access_rules of this AuthMethodAccessInfo.


        :param azure_ad_access_rules: The azure_ad_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :type: AzureADAccessRules
        """

        self._azure_ad_access_rules = azure_ad_access_rules

    @property
    def cert_access_rules(self):
        """Gets the cert_access_rules of this AuthMethodAccessInfo.  # noqa: E501


        :return: The cert_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: CertAccessRules
        """
        return self._cert_access_rules

    @cert_access_rules.setter
    def cert_access_rules(self, cert_access_rules):
        """Sets the cert_access_rules of this AuthMethodAccessInfo.


        :param cert_access_rules: The cert_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :type: CertAccessRules
        """

        self._cert_access_rules = cert_access_rules

    @property
    def cidr_whitelist(self):
        """Gets the cidr_whitelist of this AuthMethodAccessInfo.  # noqa: E501


        :return: The cidr_whitelist of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: str
        """
        return self._cidr_whitelist

    @cidr_whitelist.setter
    def cidr_whitelist(self, cidr_whitelist):
        """Sets the cidr_whitelist of this AuthMethodAccessInfo.


        :param cidr_whitelist: The cidr_whitelist of this AuthMethodAccessInfo.  # noqa: E501
        :type: str
        """

        self._cidr_whitelist = cidr_whitelist

    @property
    def email_pass_access_rules(self):
        """Gets the email_pass_access_rules of this AuthMethodAccessInfo.  # noqa: E501


        :return: The email_pass_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: EmailPassAccessRules
        """
        return self._email_pass_access_rules

    @email_pass_access_rules.setter
    def email_pass_access_rules(self, email_pass_access_rules):
        """Sets the email_pass_access_rules of this AuthMethodAccessInfo.


        :param email_pass_access_rules: The email_pass_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :type: EmailPassAccessRules
        """

        self._email_pass_access_rules = email_pass_access_rules

    @property
    def force_sub_claims(self):
        """Gets the force_sub_claims of this AuthMethodAccessInfo.  # noqa: E501

        if true the role associated with this auth method must include sub claims  # noqa: E501

        :return: The force_sub_claims of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: bool
        """
        return self._force_sub_claims

    @force_sub_claims.setter
    def force_sub_claims(self, force_sub_claims):
        """Sets the force_sub_claims of this AuthMethodAccessInfo.

        if true the role associated with this auth method must include sub claims  # noqa: E501

        :param force_sub_claims: The force_sub_claims of this AuthMethodAccessInfo.  # noqa: E501
        :type: bool
        """

        self._force_sub_claims = force_sub_claims

    @property
    def gcp_access_rules(self):
        """Gets the gcp_access_rules of this AuthMethodAccessInfo.  # noqa: E501


        :return: The gcp_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: GCPAccessRules
        """
        return self._gcp_access_rules

    @gcp_access_rules.setter
    def gcp_access_rules(self, gcp_access_rules):
        """Sets the gcp_access_rules of this AuthMethodAccessInfo.


        :param gcp_access_rules: The gcp_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :type: GCPAccessRules
        """

        self._gcp_access_rules = gcp_access_rules

    @property
    def gw_cidr_whitelist(self):
        """Gets the gw_cidr_whitelist of this AuthMethodAccessInfo.  # noqa: E501


        :return: The gw_cidr_whitelist of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: str
        """
        return self._gw_cidr_whitelist

    @gw_cidr_whitelist.setter
    def gw_cidr_whitelist(self, gw_cidr_whitelist):
        """Sets the gw_cidr_whitelist of this AuthMethodAccessInfo.


        :param gw_cidr_whitelist: The gw_cidr_whitelist of this AuthMethodAccessInfo.  # noqa: E501
        :type: str
        """

        self._gw_cidr_whitelist = gw_cidr_whitelist

    @property
    def huawei_access_rules(self):
        """Gets the huawei_access_rules of this AuthMethodAccessInfo.  # noqa: E501


        :return: The huawei_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: HuaweiAccessRules
        """
        return self._huawei_access_rules

    @huawei_access_rules.setter
    def huawei_access_rules(self, huawei_access_rules):
        """Sets the huawei_access_rules of this AuthMethodAccessInfo.


        :param huawei_access_rules: The huawei_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :type: HuaweiAccessRules
        """

        self._huawei_access_rules = huawei_access_rules

    @property
    def jwt_ttl(self):
        """Gets the jwt_ttl of this AuthMethodAccessInfo.  # noqa: E501


        :return: The jwt_ttl of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: int
        """
        return self._jwt_ttl

    @jwt_ttl.setter
    def jwt_ttl(self, jwt_ttl):
        """Sets the jwt_ttl of this AuthMethodAccessInfo.


        :param jwt_ttl: The jwt_ttl of this AuthMethodAccessInfo.  # noqa: E501
        :type: int
        """

        self._jwt_ttl = jwt_ttl

    @property
    def k8s_access_rules(self):
        """Gets the k8s_access_rules of this AuthMethodAccessInfo.  # noqa: E501


        :return: The k8s_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: KubernetesAccessRules
        """
        return self._k8s_access_rules

    @k8s_access_rules.setter
    def k8s_access_rules(self, k8s_access_rules):
        """Sets the k8s_access_rules of this AuthMethodAccessInfo.


        :param k8s_access_rules: The k8s_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :type: KubernetesAccessRules
        """

        self._k8s_access_rules = k8s_access_rules

    @property
    def ldap_access_rules(self):
        """Gets the ldap_access_rules of this AuthMethodAccessInfo.  # noqa: E501


        :return: The ldap_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: LDAPAccessRules
        """
        return self._ldap_access_rules

    @ldap_access_rules.setter
    def ldap_access_rules(self, ldap_access_rules):
        """Sets the ldap_access_rules of this AuthMethodAccessInfo.


        :param ldap_access_rules: The ldap_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :type: LDAPAccessRules
        """

        self._ldap_access_rules = ldap_access_rules

    @property
    def oauth2_access_rules(self):
        """Gets the oauth2_access_rules of this AuthMethodAccessInfo.  # noqa: E501


        :return: The oauth2_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: OAuth2AccessRules
        """
        return self._oauth2_access_rules

    @oauth2_access_rules.setter
    def oauth2_access_rules(self, oauth2_access_rules):
        """Sets the oauth2_access_rules of this AuthMethodAccessInfo.


        :param oauth2_access_rules: The oauth2_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :type: OAuth2AccessRules
        """

        self._oauth2_access_rules = oauth2_access_rules

    @property
    def oidc_access_rules(self):
        """Gets the oidc_access_rules of this AuthMethodAccessInfo.  # noqa: E501


        :return: The oidc_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: OIDCAccessRules
        """
        return self._oidc_access_rules

    @oidc_access_rules.setter
    def oidc_access_rules(self, oidc_access_rules):
        """Sets the oidc_access_rules of this AuthMethodAccessInfo.


        :param oidc_access_rules: The oidc_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :type: OIDCAccessRules
        """

        self._oidc_access_rules = oidc_access_rules

    @property
    def rules_type(self):
        """Gets the rules_type of this AuthMethodAccessInfo.  # noqa: E501


        :return: The rules_type of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: str
        """
        return self._rules_type

    @rules_type.setter
    def rules_type(self, rules_type):
        """Sets the rules_type of this AuthMethodAccessInfo.


        :param rules_type: The rules_type of this AuthMethodAccessInfo.  # noqa: E501
        :type: str
        """

        self._rules_type = rules_type

    @property
    def saml_access_rules(self):
        """Gets the saml_access_rules of this AuthMethodAccessInfo.  # noqa: E501


        :return: The saml_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: SAMLAccessRules
        """
        return self._saml_access_rules

    @saml_access_rules.setter
    def saml_access_rules(self, saml_access_rules):
        """Sets the saml_access_rules of this AuthMethodAccessInfo.


        :param saml_access_rules: The saml_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :type: SAMLAccessRules
        """

        self._saml_access_rules = saml_access_rules

    @property
    def universal_identity_access_rules(self):
        """Gets the universal_identity_access_rules of this AuthMethodAccessInfo.  # noqa: E501


        :return: The universal_identity_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :rtype: UniversalIdentityAccessRules
        """
        return self._universal_identity_access_rules

    @universal_identity_access_rules.setter
    def universal_identity_access_rules(self, universal_identity_access_rules):
        """Sets the universal_identity_access_rules of this AuthMethodAccessInfo.


        :param universal_identity_access_rules: The universal_identity_access_rules of this AuthMethodAccessInfo.  # noqa: E501
        :type: UniversalIdentityAccessRules
        """

        self._universal_identity_access_rules = universal_identity_access_rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuthMethodAccessInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuthMethodAccessInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.k8_s_auth import K8SAuth  # noqa: E501
from akeyless.rest import ApiException

class TestK8SAuth(unittest.TestCase):
    """K8SAuth unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test K8SAuth
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.k8_s_auth.K8SAuth()  # noqa: E501
        if include_optional :
            return K8SAuth(
                am_token_expiration = 56, 
                auth_method_access_id = '0', 
                auth_method_prv_key_pem = '0', 
                disable_iss_validation = True, 
                id = '0', 
                k8s_ca_cert = '0', 
                k8s_host = '0', 
                k8s_issuer = '0', 
                k8s_pub_keys_pem = [
                    '0'
                    ], 
                k8s_token_reviewer_jwt = '0', 
                name = '0', 
                protection_key = '0', 
                use_local_ca_jwt = True
            )
        else :
            return K8SAuth(
        )

    def testK8SAuth(self):
        """Test K8SAuth"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class CreateDBTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'comment': 'str',
        'db_name': 'str',
        'db_server_certificates': 'str',
        'db_server_name': 'str',
        'db_type': 'str',
        'host': 'str',
        'json': 'bool',
        'key': 'str',
        'mongodb_atlas': 'bool',
        'mongodb_atlas_api_private_key': 'str',
        'mongodb_atlas_api_public_key': 'str',
        'mongodb_atlas_project_id': 'str',
        'mongodb_default_auth_db': 'str',
        'mongodb_uri_options': 'str',
        'name': 'str',
        'oracle_service_name': 'str',
        'port': 'str',
        'pwd': 'str',
        'snowflake_account': 'str',
        'ssl': 'bool',
        'ssl_certificate': 'str',
        'token': 'str',
        'uid_token': 'str',
        'user_name': 'str'
    }

    attribute_map = {
        'comment': 'comment',
        'db_name': 'db-name',
        'db_server_certificates': 'db-server-certificates',
        'db_server_name': 'db-server-name',
        'db_type': 'db-type',
        'host': 'host',
        'json': 'json',
        'key': 'key',
        'mongodb_atlas': 'mongodb-atlas',
        'mongodb_atlas_api_private_key': 'mongodb-atlas-api-private-key',
        'mongodb_atlas_api_public_key': 'mongodb-atlas-api-public-key',
        'mongodb_atlas_project_id': 'mongodb-atlas-project-id',
        'mongodb_default_auth_db': 'mongodb-default-auth-db',
        'mongodb_uri_options': 'mongodb-uri-options',
        'name': 'name',
        'oracle_service_name': 'oracle-service-name',
        'port': 'port',
        'pwd': 'pwd',
        'snowflake_account': 'snowflake-account',
        'ssl': 'ssl',
        'ssl_certificate': 'ssl-certificate',
        'token': 'token',
        'uid_token': 'uid-token',
        'user_name': 'user-name'
    }

    def __init__(self, comment=None, db_name=None, db_server_certificates=None, db_server_name=None, db_type=None, host=None, json=None, key=None, mongodb_atlas=None, mongodb_atlas_api_private_key=None, mongodb_atlas_api_public_key=None, mongodb_atlas_project_id=None, mongodb_default_auth_db=None, mongodb_uri_options=None, name=None, oracle_service_name=None, port=None, pwd=None, snowflake_account=None, ssl=None, ssl_certificate=None, token=None, uid_token=None, user_name=None, local_vars_configuration=None):  # noqa: E501
        """CreateDBTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._comment = None
        self._db_name = None
        self._db_server_certificates = None
        self._db_server_name = None
        self._db_type = None
        self._host = None
        self._json = None
        self._key = None
        self._mongodb_atlas = None
        self._mongodb_atlas_api_private_key = None
        self._mongodb_atlas_api_public_key = None
        self._mongodb_atlas_project_id = None
        self._mongodb_default_auth_db = None
        self._mongodb_uri_options = None
        self._name = None
        self._oracle_service_name = None
        self._port = None
        self._pwd = None
        self._snowflake_account = None
        self._ssl = None
        self._ssl_certificate = None
        self._token = None
        self._uid_token = None
        self._user_name = None
        self.discriminator = None

        if comment is not None:
            self.comment = comment
        if db_name is not None:
            self.db_name = db_name
        if db_server_certificates is not None:
            self.db_server_certificates = db_server_certificates
        if db_server_name is not None:
            self.db_server_name = db_server_name
        self.db_type = db_type
        if host is not None:
            self.host = host
        if json is not None:
            self.json = json
        if key is not None:
            self.key = key
        if mongodb_atlas is not None:
            self.mongodb_atlas = mongodb_atlas
        if mongodb_atlas_api_private_key is not None:
            self.mongodb_atlas_api_private_key = mongodb_atlas_api_private_key
        if mongodb_atlas_api_public_key is not None:
            self.mongodb_atlas_api_public_key = mongodb_atlas_api_public_key
        if mongodb_atlas_project_id is not None:
            self.mongodb_atlas_project_id = mongodb_atlas_project_id
        if mongodb_default_auth_db is not None:
            self.mongodb_default_auth_db = mongodb_default_auth_db
        if mongodb_uri_options is not None:
            self.mongodb_uri_options = mongodb_uri_options
        self.name = name
        if oracle_service_name is not None:
            self.oracle_service_name = oracle_service_name
        if port is not None:
            self.port = port
        if pwd is not None:
            self.pwd = pwd
        if snowflake_account is not None:
            self.snowflake_account = snowflake_account
        if ssl is not None:
            self.ssl = ssl
        if ssl_certificate is not None:
            self.ssl_certificate = ssl_certificate
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if user_name is not None:
            self.user_name = user_name

    @property
    def comment(self):
        """Gets the comment of this CreateDBTarget.  # noqa: E501

        Comment about the target  # noqa: E501

        :return: The comment of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this CreateDBTarget.

        Comment about the target  # noqa: E501

        :param comment: The comment of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def db_name(self):
        """Gets the db_name of this CreateDBTarget.  # noqa: E501


        :return: The db_name of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """Sets the db_name of this CreateDBTarget.


        :param db_name: The db_name of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._db_name = db_name

    @property
    def db_server_certificates(self):
        """Gets the db_server_certificates of this CreateDBTarget.  # noqa: E501

        (Optional) DB server certificates  # noqa: E501

        :return: The db_server_certificates of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._db_server_certificates

    @db_server_certificates.setter
    def db_server_certificates(self, db_server_certificates):
        """Sets the db_server_certificates of this CreateDBTarget.

        (Optional) DB server certificates  # noqa: E501

        :param db_server_certificates: The db_server_certificates of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._db_server_certificates = db_server_certificates

    @property
    def db_server_name(self):
        """Gets the db_server_name of this CreateDBTarget.  # noqa: E501

        (Optional) Server name for certificate verification  # noqa: E501

        :return: The db_server_name of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._db_server_name

    @db_server_name.setter
    def db_server_name(self, db_server_name):
        """Sets the db_server_name of this CreateDBTarget.

        (Optional) Server name for certificate verification  # noqa: E501

        :param db_server_name: The db_server_name of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._db_server_name = db_server_name

    @property
    def db_type(self):
        """Gets the db_type of this CreateDBTarget.  # noqa: E501


        :return: The db_type of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._db_type

    @db_type.setter
    def db_type(self, db_type):
        """Sets the db_type of this CreateDBTarget.


        :param db_type: The db_type of this CreateDBTarget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and db_type is None:  # noqa: E501
            raise ValueError("Invalid value for `db_type`, must not be `None`")  # noqa: E501

        self._db_type = db_type

    @property
    def host(self):
        """Gets the host of this CreateDBTarget.  # noqa: E501


        :return: The host of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this CreateDBTarget.


        :param host: The host of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def json(self):
        """Gets the json of this CreateDBTarget.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this CreateDBTarget.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this CreateDBTarget.

        Set output format to JSON  # noqa: E501

        :param json: The json of this CreateDBTarget.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def key(self):
        """Gets the key of this CreateDBTarget.  # noqa: E501

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :return: The key of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this CreateDBTarget.

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :param key: The key of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def mongodb_atlas(self):
        """Gets the mongodb_atlas of this CreateDBTarget.  # noqa: E501


        :return: The mongodb_atlas of this CreateDBTarget.  # noqa: E501
        :rtype: bool
        """
        return self._mongodb_atlas

    @mongodb_atlas.setter
    def mongodb_atlas(self, mongodb_atlas):
        """Sets the mongodb_atlas of this CreateDBTarget.


        :param mongodb_atlas: The mongodb_atlas of this CreateDBTarget.  # noqa: E501
        :type: bool
        """

        self._mongodb_atlas = mongodb_atlas

    @property
    def mongodb_atlas_api_private_key(self):
        """Gets the mongodb_atlas_api_private_key of this CreateDBTarget.  # noqa: E501

        MongoDB Atlas private key  # noqa: E501

        :return: The mongodb_atlas_api_private_key of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._mongodb_atlas_api_private_key

    @mongodb_atlas_api_private_key.setter
    def mongodb_atlas_api_private_key(self, mongodb_atlas_api_private_key):
        """Sets the mongodb_atlas_api_private_key of this CreateDBTarget.

        MongoDB Atlas private key  # noqa: E501

        :param mongodb_atlas_api_private_key: The mongodb_atlas_api_private_key of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._mongodb_atlas_api_private_key = mongodb_atlas_api_private_key

    @property
    def mongodb_atlas_api_public_key(self):
        """Gets the mongodb_atlas_api_public_key of this CreateDBTarget.  # noqa: E501

        MongoDB Atlas public key  # noqa: E501

        :return: The mongodb_atlas_api_public_key of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._mongodb_atlas_api_public_key

    @mongodb_atlas_api_public_key.setter
    def mongodb_atlas_api_public_key(self, mongodb_atlas_api_public_key):
        """Sets the mongodb_atlas_api_public_key of this CreateDBTarget.

        MongoDB Atlas public key  # noqa: E501

        :param mongodb_atlas_api_public_key: The mongodb_atlas_api_public_key of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._mongodb_atlas_api_public_key = mongodb_atlas_api_public_key

    @property
    def mongodb_atlas_project_id(self):
        """Gets the mongodb_atlas_project_id of this CreateDBTarget.  # noqa: E501

        MongoDB Atlas project ID  # noqa: E501

        :return: The mongodb_atlas_project_id of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._mongodb_atlas_project_id

    @mongodb_atlas_project_id.setter
    def mongodb_atlas_project_id(self, mongodb_atlas_project_id):
        """Sets the mongodb_atlas_project_id of this CreateDBTarget.

        MongoDB Atlas project ID  # noqa: E501

        :param mongodb_atlas_project_id: The mongodb_atlas_project_id of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._mongodb_atlas_project_id = mongodb_atlas_project_id

    @property
    def mongodb_default_auth_db(self):
        """Gets the mongodb_default_auth_db of this CreateDBTarget.  # noqa: E501

        MongoDB server default authentication database  # noqa: E501

        :return: The mongodb_default_auth_db of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._mongodb_default_auth_db

    @mongodb_default_auth_db.setter
    def mongodb_default_auth_db(self, mongodb_default_auth_db):
        """Sets the mongodb_default_auth_db of this CreateDBTarget.

        MongoDB server default authentication database  # noqa: E501

        :param mongodb_default_auth_db: The mongodb_default_auth_db of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._mongodb_default_auth_db = mongodb_default_auth_db

    @property
    def mongodb_uri_options(self):
        """Gets the mongodb_uri_options of this CreateDBTarget.  # noqa: E501

        MongoDB server URI options  # noqa: E501

        :return: The mongodb_uri_options of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._mongodb_uri_options

    @mongodb_uri_options.setter
    def mongodb_uri_options(self, mongodb_uri_options):
        """Sets the mongodb_uri_options of this CreateDBTarget.

        MongoDB server URI options  # noqa: E501

        :param mongodb_uri_options: The mongodb_uri_options of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._mongodb_uri_options = mongodb_uri_options

    @property
    def name(self):
        """Gets the name of this CreateDBTarget.  # noqa: E501

        Target name  # noqa: E501

        :return: The name of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateDBTarget.

        Target name  # noqa: E501

        :param name: The name of this CreateDBTarget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def oracle_service_name(self):
        """Gets the oracle_service_name of this CreateDBTarget.  # noqa: E501


        :return: The oracle_service_name of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._oracle_service_name

    @oracle_service_name.setter
    def oracle_service_name(self, oracle_service_name):
        """Sets the oracle_service_name of this CreateDBTarget.


        :param oracle_service_name: The oracle_service_name of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._oracle_service_name = oracle_service_name

    @property
    def port(self):
        """Gets the port of this CreateDBTarget.  # noqa: E501


        :return: The port of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this CreateDBTarget.


        :param port: The port of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._port = port

    @property
    def pwd(self):
        """Gets the pwd of this CreateDBTarget.  # noqa: E501


        :return: The pwd of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._pwd

    @pwd.setter
    def pwd(self, pwd):
        """Sets the pwd of this CreateDBTarget.


        :param pwd: The pwd of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._pwd = pwd

    @property
    def snowflake_account(self):
        """Gets the snowflake_account of this CreateDBTarget.  # noqa: E501


        :return: The snowflake_account of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._snowflake_account

    @snowflake_account.setter
    def snowflake_account(self, snowflake_account):
        """Sets the snowflake_account of this CreateDBTarget.


        :param snowflake_account: The snowflake_account of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._snowflake_account = snowflake_account

    @property
    def ssl(self):
        """Gets the ssl of this CreateDBTarget.  # noqa: E501

        SSL connection mode  # noqa: E501

        :return: The ssl of this CreateDBTarget.  # noqa: E501
        :rtype: bool
        """
        return self._ssl

    @ssl.setter
    def ssl(self, ssl):
        """Sets the ssl of this CreateDBTarget.

        SSL connection mode  # noqa: E501

        :param ssl: The ssl of this CreateDBTarget.  # noqa: E501
        :type: bool
        """

        self._ssl = ssl

    @property
    def ssl_certificate(self):
        """Gets the ssl_certificate of this CreateDBTarget.  # noqa: E501

        SSL connection certificate  # noqa: E501

        :return: The ssl_certificate of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._ssl_certificate

    @ssl_certificate.setter
    def ssl_certificate(self, ssl_certificate):
        """Sets the ssl_certificate of this CreateDBTarget.

        SSL connection certificate  # noqa: E501

        :param ssl_certificate: The ssl_certificate of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._ssl_certificate = ssl_certificate

    @property
    def token(self):
        """Gets the token of this CreateDBTarget.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this CreateDBTarget.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this CreateDBTarget.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this CreateDBTarget.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def user_name(self):
        """Gets the user_name of this CreateDBTarget.  # noqa: E501


        :return: The user_name of this CreateDBTarget.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this CreateDBTarget.


        :param user_name: The user_name of this CreateDBTarget.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDBTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateDBTarget):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.gateway_update_producer_certificate_automation import GatewayUpdateProducerCertificateAutomation  # noqa: E501
from akeyless.rest import ApiException

class TestGatewayUpdateProducerCertificateAutomation(unittest.TestCase):
    """GatewayUpdateProducerCertificateAutomation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GatewayUpdateProducerCertificateAutomation
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.gateway_update_producer_certificate_automation.GatewayUpdateProducerCertificateAutomation()  # noqa: E501
        if include_optional :
            return GatewayUpdateProducerCertificateAutomation(
                admin_rotation_interval_days = 56, 
                allow_subdomains = True, 
                allowed_domains = [
                    '0'
                    ], 
                auto_generated_folder = '0', 
                enable_admin_rotation = True, 
                name = '0', 
                new_name = '0', 
                password = '0', 
                producer_encryption_key_name = '0', 
                root_first_in_chain = True, 
                sign_using_akeyless_pki = True, 
                signer_key_name = '0', 
                store_private_key = True, 
                tags = [
                    '0'
                    ], 
                target_name = '0', 
                token = '0', 
                uid_token = '0', 
                user_ttl = '0', 
                username = '0', 
                venafi_api_key = '0', 
                venafi_baseurl = '0', 
                venafi_password = '0', 
                venafi_use_tpp = True, 
                venafi_username = '0', 
                venafi_zone = '0'
            )
        else :
            return GatewayUpdateProducerCertificateAutomation(
                name = '0',
        )

    def testGatewayUpdateProducerCertificateAutomation(self):
        """Test GatewayUpdateProducerCertificateAutomation"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayUpdateProducerGcp(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'delete_protection': 'str',
        'gcp_cred_type': 'str',
        'gcp_key': 'str',
        'gcp_key_algo': 'str',
        'gcp_sa_email': 'str',
        'gcp_token_scopes': 'str',
        'json': 'bool',
        'name': 'str',
        'new_name': 'str',
        'producer_encryption_key_name': 'str',
        'role_binding': 'str',
        'service_account_type': 'str',
        'tags': 'list[str]',
        'target_name': 'str',
        'token': 'str',
        'uid_token': 'str',
        'user_ttl': 'str'
    }

    attribute_map = {
        'delete_protection': 'delete_protection',
        'gcp_cred_type': 'gcp-cred-type',
        'gcp_key': 'gcp-key',
        'gcp_key_algo': 'gcp-key-algo',
        'gcp_sa_email': 'gcp-sa-email',
        'gcp_token_scopes': 'gcp-token-scopes',
        'json': 'json',
        'name': 'name',
        'new_name': 'new-name',
        'producer_encryption_key_name': 'producer-encryption-key-name',
        'role_binding': 'role-binding',
        'service_account_type': 'service-account-type',
        'tags': 'tags',
        'target_name': 'target-name',
        'token': 'token',
        'uid_token': 'uid-token',
        'user_ttl': 'user-ttl'
    }

    def __init__(self, delete_protection=None, gcp_cred_type=None, gcp_key=None, gcp_key_algo=None, gcp_sa_email=None, gcp_token_scopes=None, json=None, name=None, new_name=None, producer_encryption_key_name=None, role_binding=None, service_account_type='fixed', tags=None, target_name=None, token=None, uid_token=None, user_ttl='60m', local_vars_configuration=None):  # noqa: E501
        """GatewayUpdateProducerGcp - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._delete_protection = None
        self._gcp_cred_type = None
        self._gcp_key = None
        self._gcp_key_algo = None
        self._gcp_sa_email = None
        self._gcp_token_scopes = None
        self._json = None
        self._name = None
        self._new_name = None
        self._producer_encryption_key_name = None
        self._role_binding = None
        self._service_account_type = None
        self._tags = None
        self._target_name = None
        self._token = None
        self._uid_token = None
        self._user_ttl = None
        self.discriminator = None

        if delete_protection is not None:
            self.delete_protection = delete_protection
        if gcp_cred_type is not None:
            self.gcp_cred_type = gcp_cred_type
        if gcp_key is not None:
            self.gcp_key = gcp_key
        if gcp_key_algo is not None:
            self.gcp_key_algo = gcp_key_algo
        if gcp_sa_email is not None:
            self.gcp_sa_email = gcp_sa_email
        if gcp_token_scopes is not None:
            self.gcp_token_scopes = gcp_token_scopes
        if json is not None:
            self.json = json
        self.name = name
        if new_name is not None:
            self.new_name = new_name
        if producer_encryption_key_name is not None:
            self.producer_encryption_key_name = producer_encryption_key_name
        if role_binding is not None:
            self.role_binding = role_binding
        self.service_account_type = service_account_type
        if tags is not None:
            self.tags = tags
        if target_name is not None:
            self.target_name = target_name
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if user_ttl is not None:
            self.user_ttl = user_ttl

    @property
    def delete_protection(self):
        """Gets the delete_protection of this GatewayUpdateProducerGcp.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this GatewayUpdateProducerGcp.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def gcp_cred_type(self):
        """Gets the gcp_cred_type of this GatewayUpdateProducerGcp.  # noqa: E501


        :return: The gcp_cred_type of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._gcp_cred_type

    @gcp_cred_type.setter
    def gcp_cred_type(self, gcp_cred_type):
        """Sets the gcp_cred_type of this GatewayUpdateProducerGcp.


        :param gcp_cred_type: The gcp_cred_type of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """

        self._gcp_cred_type = gcp_cred_type

    @property
    def gcp_key(self):
        """Gets the gcp_key of this GatewayUpdateProducerGcp.  # noqa: E501

        Base64-encoded service account private key text  # noqa: E501

        :return: The gcp_key of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._gcp_key

    @gcp_key.setter
    def gcp_key(self, gcp_key):
        """Sets the gcp_key of this GatewayUpdateProducerGcp.

        Base64-encoded service account private key text  # noqa: E501

        :param gcp_key: The gcp_key of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """

        self._gcp_key = gcp_key

    @property
    def gcp_key_algo(self):
        """Gets the gcp_key_algo of this GatewayUpdateProducerGcp.  # noqa: E501

        Service account key algorithm, e.g. KEY_ALG_RSA_1024  # noqa: E501

        :return: The gcp_key_algo of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._gcp_key_algo

    @gcp_key_algo.setter
    def gcp_key_algo(self, gcp_key_algo):
        """Sets the gcp_key_algo of this GatewayUpdateProducerGcp.

        Service account key algorithm, e.g. KEY_ALG_RSA_1024  # noqa: E501

        :param gcp_key_algo: The gcp_key_algo of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """

        self._gcp_key_algo = gcp_key_algo

    @property
    def gcp_sa_email(self):
        """Gets the gcp_sa_email of this GatewayUpdateProducerGcp.  # noqa: E501

        The email of the fixed service acocunt to generate keys or tokens for. (revelant for service-account-type=fixed)  # noqa: E501

        :return: The gcp_sa_email of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._gcp_sa_email

    @gcp_sa_email.setter
    def gcp_sa_email(self, gcp_sa_email):
        """Sets the gcp_sa_email of this GatewayUpdateProducerGcp.

        The email of the fixed service acocunt to generate keys or tokens for. (revelant for service-account-type=fixed)  # noqa: E501

        :param gcp_sa_email: The gcp_sa_email of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """

        self._gcp_sa_email = gcp_sa_email

    @property
    def gcp_token_scopes(self):
        """Gets the gcp_token_scopes of this GatewayUpdateProducerGcp.  # noqa: E501

        Access token scopes list, e.g. scope1,scope2  # noqa: E501

        :return: The gcp_token_scopes of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._gcp_token_scopes

    @gcp_token_scopes.setter
    def gcp_token_scopes(self, gcp_token_scopes):
        """Sets the gcp_token_scopes of this GatewayUpdateProducerGcp.

        Access token scopes list, e.g. scope1,scope2  # noqa: E501

        :param gcp_token_scopes: The gcp_token_scopes of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """

        self._gcp_token_scopes = gcp_token_scopes

    @property
    def json(self):
        """Gets the json of this GatewayUpdateProducerGcp.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayUpdateProducerGcp.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this GatewayUpdateProducerGcp.  # noqa: E501

        Producer name  # noqa: E501

        :return: The name of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayUpdateProducerGcp.

        Producer name  # noqa: E501

        :param name: The name of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_name(self):
        """Gets the new_name of this GatewayUpdateProducerGcp.  # noqa: E501

        Producer name  # noqa: E501

        :return: The new_name of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this GatewayUpdateProducerGcp.

        Producer name  # noqa: E501

        :param new_name: The new_name of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def producer_encryption_key_name(self):
        """Gets the producer_encryption_key_name of this GatewayUpdateProducerGcp.  # noqa: E501

        Dynamic producer encryption key  # noqa: E501

        :return: The producer_encryption_key_name of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._producer_encryption_key_name

    @producer_encryption_key_name.setter
    def producer_encryption_key_name(self, producer_encryption_key_name):
        """Sets the producer_encryption_key_name of this GatewayUpdateProducerGcp.

        Dynamic producer encryption key  # noqa: E501

        :param producer_encryption_key_name: The producer_encryption_key_name of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """

        self._producer_encryption_key_name = producer_encryption_key_name

    @property
    def role_binding(self):
        """Gets the role_binding of this GatewayUpdateProducerGcp.  # noqa: E501

        Role binding definitions in json format  # noqa: E501

        :return: The role_binding of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._role_binding

    @role_binding.setter
    def role_binding(self, role_binding):
        """Sets the role_binding of this GatewayUpdateProducerGcp.

        Role binding definitions in json format  # noqa: E501

        :param role_binding: The role_binding of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """

        self._role_binding = role_binding

    @property
    def service_account_type(self):
        """Gets the service_account_type of this GatewayUpdateProducerGcp.  # noqa: E501

        The type of the gcp dynamic secret. Options[fixed, dynamic]  # noqa: E501

        :return: The service_account_type of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._service_account_type

    @service_account_type.setter
    def service_account_type(self, service_account_type):
        """Sets the service_account_type of this GatewayUpdateProducerGcp.

        The type of the gcp dynamic secret. Options[fixed, dynamic]  # noqa: E501

        :param service_account_type: The service_account_type of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and service_account_type is None:  # noqa: E501
            raise ValueError("Invalid value for `service_account_type`, must not be `None`")  # noqa: E501

        self._service_account_type = service_account_type

    @property
    def tags(self):
        """Gets the tags of this GatewayUpdateProducerGcp.  # noqa: E501

        List of the tags attached to this secret  # noqa: E501

        :return: The tags of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this GatewayUpdateProducerGcp.

        List of the tags attached to this secret  # noqa: E501

        :param tags: The tags of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def target_name(self):
        """Gets the target_name of this GatewayUpdateProducerGcp.  # noqa: E501

        Target name  # noqa: E501

        :return: The target_name of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this GatewayUpdateProducerGcp.

        Target name  # noqa: E501

        :param target_name: The target_name of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """

        self._target_name = target_name

    @property
    def token(self):
        """Gets the token of this GatewayUpdateProducerGcp.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayUpdateProducerGcp.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayUpdateProducerGcp.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayUpdateProducerGcp.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def user_ttl(self):
        """Gets the user_ttl of this GatewayUpdateProducerGcp.  # noqa: E501

        User TTL  # noqa: E501

        :return: The user_ttl of this GatewayUpdateProducerGcp.  # noqa: E501
        :rtype: str
        """
        return self._user_ttl

    @user_ttl.setter
    def user_ttl(self, user_ttl):
        """Sets the user_ttl of this GatewayUpdateProducerGcp.

        User TTL  # noqa: E501

        :param user_ttl: The user_ttl of this GatewayUpdateProducerGcp.  # noqa: E501
        :type: str
        """

        self._user_ttl = user_ttl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayUpdateProducerGcp):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayUpdateProducerGcp):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.create_pki_cert_issuer import CreatePKICertIssuer  # noqa: E501
from akeyless.rest import ApiException

class TestCreatePKICertIssuer(unittest.TestCase):
    """CreatePKICertIssuer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreatePKICertIssuer
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.create_pki_cert_issuer.CreatePKICertIssuer()  # noqa: E501
        if include_optional :
            return CreatePKICertIssuer(
                allow_any_name = True, 
                allow_subdomains = True, 
                allowed_domains = '0', 
                allowed_uri_sans = '0', 
                client_flag = True, 
                code_signing_flag = True, 
                country = '0', 
                key_usage = 'DigitalSignature,KeyAgreement,KeyEncipherment', 
                locality = '0', 
                metadata = '0', 
                name = '0', 
                not_enforce_hostnames = True, 
                not_require_cn = True, 
                organizational_units = '0', 
                organizations = '0', 
                postal_code = '0', 
                province = '0', 
                server_flag = True, 
                signer_key_name = '0', 
                street_address = '0', 
                token = '0', 
                ttl = 56, 
                uid_token = '0'
            )
        else :
            return CreatePKICertIssuer(
                name = '0',
                signer_key_name = '0',
                ttl = 56,
        )

    def testCreatePKICertIssuer(self):
        """Test CreatePKICertIssuer"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.update_auth_method_azure_ad import UpdateAuthMethodAzureAD  # noqa: E501
from akeyless.rest import ApiException

class TestUpdateAuthMethodAzureAD(unittest.TestCase):
    """UpdateAuthMethodAzureAD unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UpdateAuthMethodAzureAD
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.update_auth_method_azure_ad.UpdateAuthMethodAzureAD()  # noqa: E501
        if include_optional :
            return UpdateAuthMethodAzureAD(
                access_expires = 56, 
                audience = 'https://management.azure.com/', 
                bound_group_id = [
                    '0'
                    ], 
                bound_ips = [
                    '0'
                    ], 
                bound_providers = [
                    '0'
                    ], 
                bound_resource_id = [
                    '0'
                    ], 
                bound_resource_names = [
                    '0'
                    ], 
                bound_resource_types = [
                    '0'
                    ], 
                bound_rg_id = [
                    '0'
                    ], 
                bound_spid = [
                    '0'
                    ], 
                bound_sub_id = [
                    '0'
                    ], 
                bound_tenant_id = '0', 
                force_sub_claims = True, 
                issuer = 'https://sts.windows.net/---bound_tenant_id---', 
                jwks_uri = 'https://login.microsoftonline.com/common/discovery/keys', 
                name = '0', 
                new_name = '0', 
                password = '0', 
                token = '0', 
                uid_token = '0', 
                username = '0'
            )
        else :
            return UpdateAuthMethodAzureAD(
                bound_tenant_id = '0',
                name = '0',
        )

    def testUpdateAuthMethodAzureAD(self):
        """Test UpdateAuthMethodAzureAD"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayUpdateProducerAws(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_mode': 'str',
        'admin_rotation_interval_days': 'int',
        'aws_access_key_id': 'str',
        'aws_access_secret_key': 'str',
        'aws_role_arns': 'str',
        'aws_user_console_access': 'bool',
        'aws_user_groups': 'str',
        'aws_user_policies': 'str',
        'aws_user_programmatic_access': 'bool',
        'delete_protection': 'str',
        'enable_admin_rotation': 'bool',
        'json': 'bool',
        'name': 'str',
        'new_name': 'str',
        'producer_encryption_key_name': 'str',
        'region': 'str',
        'secure_access_aws_account_id': 'str',
        'secure_access_aws_native_cli': 'bool',
        'secure_access_bastion_issuer': 'str',
        'secure_access_enable': 'str',
        'secure_access_web': 'bool',
        'secure_access_web_browsing': 'bool',
        'secure_access_web_proxy': 'bool',
        'tags': 'list[str]',
        'target_name': 'str',
        'token': 'str',
        'uid_token': 'str',
        'user_ttl': 'str'
    }

    attribute_map = {
        'access_mode': 'access-mode',
        'admin_rotation_interval_days': 'admin-rotation-interval-days',
        'aws_access_key_id': 'aws-access-key-id',
        'aws_access_secret_key': 'aws-access-secret-key',
        'aws_role_arns': 'aws-role-arns',
        'aws_user_console_access': 'aws-user-console-access',
        'aws_user_groups': 'aws-user-groups',
        'aws_user_policies': 'aws-user-policies',
        'aws_user_programmatic_access': 'aws-user-programmatic-access',
        'delete_protection': 'delete_protection',
        'enable_admin_rotation': 'enable-admin-rotation',
        'json': 'json',
        'name': 'name',
        'new_name': 'new-name',
        'producer_encryption_key_name': 'producer-encryption-key-name',
        'region': 'region',
        'secure_access_aws_account_id': 'secure-access-aws-account-id',
        'secure_access_aws_native_cli': 'secure-access-aws-native-cli',
        'secure_access_bastion_issuer': 'secure-access-bastion-issuer',
        'secure_access_enable': 'secure-access-enable',
        'secure_access_web': 'secure-access-web',
        'secure_access_web_browsing': 'secure-access-web-browsing',
        'secure_access_web_proxy': 'secure-access-web-proxy',
        'tags': 'tags',
        'target_name': 'target-name',
        'token': 'token',
        'uid_token': 'uid-token',
        'user_ttl': 'user-ttl'
    }

    def __init__(self, access_mode=None, admin_rotation_interval_days=0, aws_access_key_id=None, aws_access_secret_key=None, aws_role_arns=None, aws_user_console_access=False, aws_user_groups=None, aws_user_policies=None, aws_user_programmatic_access=True, delete_protection=None, enable_admin_rotation=False, json=None, name=None, new_name=None, producer_encryption_key_name=None, region='us-east-2', secure_access_aws_account_id=None, secure_access_aws_native_cli=None, secure_access_bastion_issuer=None, secure_access_enable=None, secure_access_web=None, secure_access_web_browsing=None, secure_access_web_proxy=None, tags=None, target_name=None, token=None, uid_token=None, user_ttl='60m', local_vars_configuration=None):  # noqa: E501
        """GatewayUpdateProducerAws - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_mode = None
        self._admin_rotation_interval_days = None
        self._aws_access_key_id = None
        self._aws_access_secret_key = None
        self._aws_role_arns = None
        self._aws_user_console_access = None
        self._aws_user_groups = None
        self._aws_user_policies = None
        self._aws_user_programmatic_access = None
        self._delete_protection = None
        self._enable_admin_rotation = None
        self._json = None
        self._name = None
        self._new_name = None
        self._producer_encryption_key_name = None
        self._region = None
        self._secure_access_aws_account_id = None
        self._secure_access_aws_native_cli = None
        self._secure_access_bastion_issuer = None
        self._secure_access_enable = None
        self._secure_access_web = None
        self._secure_access_web_browsing = None
        self._secure_access_web_proxy = None
        self._tags = None
        self._target_name = None
        self._token = None
        self._uid_token = None
        self._user_ttl = None
        self.discriminator = None

        if access_mode is not None:
            self.access_mode = access_mode
        if admin_rotation_interval_days is not None:
            self.admin_rotation_interval_days = admin_rotation_interval_days
        if aws_access_key_id is not None:
            self.aws_access_key_id = aws_access_key_id
        if aws_access_secret_key is not None:
            self.aws_access_secret_key = aws_access_secret_key
        if aws_role_arns is not None:
            self.aws_role_arns = aws_role_arns
        if aws_user_console_access is not None:
            self.aws_user_console_access = aws_user_console_access
        if aws_user_groups is not None:
            self.aws_user_groups = aws_user_groups
        if aws_user_policies is not None:
            self.aws_user_policies = aws_user_policies
        if aws_user_programmatic_access is not None:
            self.aws_user_programmatic_access = aws_user_programmatic_access
        if delete_protection is not None:
            self.delete_protection = delete_protection
        if enable_admin_rotation is not None:
            self.enable_admin_rotation = enable_admin_rotation
        if json is not None:
            self.json = json
        self.name = name
        if new_name is not None:
            self.new_name = new_name
        if producer_encryption_key_name is not None:
            self.producer_encryption_key_name = producer_encryption_key_name
        if region is not None:
            self.region = region
        if secure_access_aws_account_id is not None:
            self.secure_access_aws_account_id = secure_access_aws_account_id
        if secure_access_aws_native_cli is not None:
            self.secure_access_aws_native_cli = secure_access_aws_native_cli
        if secure_access_bastion_issuer is not None:
            self.secure_access_bastion_issuer = secure_access_bastion_issuer
        if secure_access_enable is not None:
            self.secure_access_enable = secure_access_enable
        if secure_access_web is not None:
            self.secure_access_web = secure_access_web
        if secure_access_web_browsing is not None:
            self.secure_access_web_browsing = secure_access_web_browsing
        if secure_access_web_proxy is not None:
            self.secure_access_web_proxy = secure_access_web_proxy
        if tags is not None:
            self.tags = tags
        if target_name is not None:
            self.target_name = target_name
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if user_ttl is not None:
            self.user_ttl = user_ttl

    @property
    def access_mode(self):
        """Gets the access_mode of this GatewayUpdateProducerAws.  # noqa: E501


        :return: The access_mode of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._access_mode

    @access_mode.setter
    def access_mode(self, access_mode):
        """Sets the access_mode of this GatewayUpdateProducerAws.


        :param access_mode: The access_mode of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._access_mode = access_mode

    @property
    def admin_rotation_interval_days(self):
        """Gets the admin_rotation_interval_days of this GatewayUpdateProducerAws.  # noqa: E501

        Admin credentials rotation interval (days)  # noqa: E501

        :return: The admin_rotation_interval_days of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: int
        """
        return self._admin_rotation_interval_days

    @admin_rotation_interval_days.setter
    def admin_rotation_interval_days(self, admin_rotation_interval_days):
        """Sets the admin_rotation_interval_days of this GatewayUpdateProducerAws.

        Admin credentials rotation interval (days)  # noqa: E501

        :param admin_rotation_interval_days: The admin_rotation_interval_days of this GatewayUpdateProducerAws.  # noqa: E501
        :type: int
        """

        self._admin_rotation_interval_days = admin_rotation_interval_days

    @property
    def aws_access_key_id(self):
        """Gets the aws_access_key_id of this GatewayUpdateProducerAws.  # noqa: E501

        Access Key ID  # noqa: E501

        :return: The aws_access_key_id of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._aws_access_key_id

    @aws_access_key_id.setter
    def aws_access_key_id(self, aws_access_key_id):
        """Sets the aws_access_key_id of this GatewayUpdateProducerAws.

        Access Key ID  # noqa: E501

        :param aws_access_key_id: The aws_access_key_id of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._aws_access_key_id = aws_access_key_id

    @property
    def aws_access_secret_key(self):
        """Gets the aws_access_secret_key of this GatewayUpdateProducerAws.  # noqa: E501

        Secret Access Key  # noqa: E501

        :return: The aws_access_secret_key of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._aws_access_secret_key

    @aws_access_secret_key.setter
    def aws_access_secret_key(self, aws_access_secret_key):
        """Sets the aws_access_secret_key of this GatewayUpdateProducerAws.

        Secret Access Key  # noqa: E501

        :param aws_access_secret_key: The aws_access_secret_key of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._aws_access_secret_key = aws_access_secret_key

    @property
    def aws_role_arns(self):
        """Gets the aws_role_arns of this GatewayUpdateProducerAws.  # noqa: E501

        AWS Role ARNs to be used in the Assume Role operation (relevant only for assume_role mode)  # noqa: E501

        :return: The aws_role_arns of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._aws_role_arns

    @aws_role_arns.setter
    def aws_role_arns(self, aws_role_arns):
        """Sets the aws_role_arns of this GatewayUpdateProducerAws.

        AWS Role ARNs to be used in the Assume Role operation (relevant only for assume_role mode)  # noqa: E501

        :param aws_role_arns: The aws_role_arns of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._aws_role_arns = aws_role_arns

    @property
    def aws_user_console_access(self):
        """Gets the aws_user_console_access of this GatewayUpdateProducerAws.  # noqa: E501

        AWS User console access  # noqa: E501

        :return: The aws_user_console_access of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: bool
        """
        return self._aws_user_console_access

    @aws_user_console_access.setter
    def aws_user_console_access(self, aws_user_console_access):
        """Sets the aws_user_console_access of this GatewayUpdateProducerAws.

        AWS User console access  # noqa: E501

        :param aws_user_console_access: The aws_user_console_access of this GatewayUpdateProducerAws.  # noqa: E501
        :type: bool
        """

        self._aws_user_console_access = aws_user_console_access

    @property
    def aws_user_groups(self):
        """Gets the aws_user_groups of this GatewayUpdateProducerAws.  # noqa: E501

        AWS User groups  # noqa: E501

        :return: The aws_user_groups of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._aws_user_groups

    @aws_user_groups.setter
    def aws_user_groups(self, aws_user_groups):
        """Sets the aws_user_groups of this GatewayUpdateProducerAws.

        AWS User groups  # noqa: E501

        :param aws_user_groups: The aws_user_groups of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._aws_user_groups = aws_user_groups

    @property
    def aws_user_policies(self):
        """Gets the aws_user_policies of this GatewayUpdateProducerAws.  # noqa: E501

        AWS User policies  # noqa: E501

        :return: The aws_user_policies of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._aws_user_policies

    @aws_user_policies.setter
    def aws_user_policies(self, aws_user_policies):
        """Sets the aws_user_policies of this GatewayUpdateProducerAws.

        AWS User policies  # noqa: E501

        :param aws_user_policies: The aws_user_policies of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._aws_user_policies = aws_user_policies

    @property
    def aws_user_programmatic_access(self):
        """Gets the aws_user_programmatic_access of this GatewayUpdateProducerAws.  # noqa: E501

        AWS User programmatic access  # noqa: E501

        :return: The aws_user_programmatic_access of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: bool
        """
        return self._aws_user_programmatic_access

    @aws_user_programmatic_access.setter
    def aws_user_programmatic_access(self, aws_user_programmatic_access):
        """Sets the aws_user_programmatic_access of this GatewayUpdateProducerAws.

        AWS User programmatic access  # noqa: E501

        :param aws_user_programmatic_access: The aws_user_programmatic_access of this GatewayUpdateProducerAws.  # noqa: E501
        :type: bool
        """

        self._aws_user_programmatic_access = aws_user_programmatic_access

    @property
    def delete_protection(self):
        """Gets the delete_protection of this GatewayUpdateProducerAws.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this GatewayUpdateProducerAws.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def enable_admin_rotation(self):
        """Gets the enable_admin_rotation of this GatewayUpdateProducerAws.  # noqa: E501

        Automatic admin credentials rotation  # noqa: E501

        :return: The enable_admin_rotation of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: bool
        """
        return self._enable_admin_rotation

    @enable_admin_rotation.setter
    def enable_admin_rotation(self, enable_admin_rotation):
        """Sets the enable_admin_rotation of this GatewayUpdateProducerAws.

        Automatic admin credentials rotation  # noqa: E501

        :param enable_admin_rotation: The enable_admin_rotation of this GatewayUpdateProducerAws.  # noqa: E501
        :type: bool
        """

        self._enable_admin_rotation = enable_admin_rotation

    @property
    def json(self):
        """Gets the json of this GatewayUpdateProducerAws.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayUpdateProducerAws.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayUpdateProducerAws.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this GatewayUpdateProducerAws.  # noqa: E501

        Producer name  # noqa: E501

        :return: The name of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayUpdateProducerAws.

        Producer name  # noqa: E501

        :param name: The name of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_name(self):
        """Gets the new_name of this GatewayUpdateProducerAws.  # noqa: E501

        Producer name  # noqa: E501

        :return: The new_name of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this GatewayUpdateProducerAws.

        Producer name  # noqa: E501

        :param new_name: The new_name of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def producer_encryption_key_name(self):
        """Gets the producer_encryption_key_name of this GatewayUpdateProducerAws.  # noqa: E501

        Dynamic producer encryption key  # noqa: E501

        :return: The producer_encryption_key_name of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._producer_encryption_key_name

    @producer_encryption_key_name.setter
    def producer_encryption_key_name(self, producer_encryption_key_name):
        """Sets the producer_encryption_key_name of this GatewayUpdateProducerAws.

        Dynamic producer encryption key  # noqa: E501

        :param producer_encryption_key_name: The producer_encryption_key_name of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._producer_encryption_key_name = producer_encryption_key_name

    @property
    def region(self):
        """Gets the region of this GatewayUpdateProducerAws.  # noqa: E501

        Region  # noqa: E501

        :return: The region of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this GatewayUpdateProducerAws.

        Region  # noqa: E501

        :param region: The region of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._region = region

    @property
    def secure_access_aws_account_id(self):
        """Gets the secure_access_aws_account_id of this GatewayUpdateProducerAws.  # noqa: E501


        :return: The secure_access_aws_account_id of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_aws_account_id

    @secure_access_aws_account_id.setter
    def secure_access_aws_account_id(self, secure_access_aws_account_id):
        """Sets the secure_access_aws_account_id of this GatewayUpdateProducerAws.


        :param secure_access_aws_account_id: The secure_access_aws_account_id of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._secure_access_aws_account_id = secure_access_aws_account_id

    @property
    def secure_access_aws_native_cli(self):
        """Gets the secure_access_aws_native_cli of this GatewayUpdateProducerAws.  # noqa: E501


        :return: The secure_access_aws_native_cli of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_aws_native_cli

    @secure_access_aws_native_cli.setter
    def secure_access_aws_native_cli(self, secure_access_aws_native_cli):
        """Sets the secure_access_aws_native_cli of this GatewayUpdateProducerAws.


        :param secure_access_aws_native_cli: The secure_access_aws_native_cli of this GatewayUpdateProducerAws.  # noqa: E501
        :type: bool
        """

        self._secure_access_aws_native_cli = secure_access_aws_native_cli

    @property
    def secure_access_bastion_issuer(self):
        """Gets the secure_access_bastion_issuer of this GatewayUpdateProducerAws.  # noqa: E501


        :return: The secure_access_bastion_issuer of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_bastion_issuer

    @secure_access_bastion_issuer.setter
    def secure_access_bastion_issuer(self, secure_access_bastion_issuer):
        """Sets the secure_access_bastion_issuer of this GatewayUpdateProducerAws.


        :param secure_access_bastion_issuer: The secure_access_bastion_issuer of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._secure_access_bastion_issuer = secure_access_bastion_issuer

    @property
    def secure_access_enable(self):
        """Gets the secure_access_enable of this GatewayUpdateProducerAws.  # noqa: E501


        :return: The secure_access_enable of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_enable

    @secure_access_enable.setter
    def secure_access_enable(self, secure_access_enable):
        """Sets the secure_access_enable of this GatewayUpdateProducerAws.


        :param secure_access_enable: The secure_access_enable of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._secure_access_enable = secure_access_enable

    @property
    def secure_access_web(self):
        """Gets the secure_access_web of this GatewayUpdateProducerAws.  # noqa: E501


        :return: The secure_access_web of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_web

    @secure_access_web.setter
    def secure_access_web(self, secure_access_web):
        """Sets the secure_access_web of this GatewayUpdateProducerAws.


        :param secure_access_web: The secure_access_web of this GatewayUpdateProducerAws.  # noqa: E501
        :type: bool
        """

        self._secure_access_web = secure_access_web

    @property
    def secure_access_web_browsing(self):
        """Gets the secure_access_web_browsing of this GatewayUpdateProducerAws.  # noqa: E501


        :return: The secure_access_web_browsing of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_web_browsing

    @secure_access_web_browsing.setter
    def secure_access_web_browsing(self, secure_access_web_browsing):
        """Sets the secure_access_web_browsing of this GatewayUpdateProducerAws.


        :param secure_access_web_browsing: The secure_access_web_browsing of this GatewayUpdateProducerAws.  # noqa: E501
        :type: bool
        """

        self._secure_access_web_browsing = secure_access_web_browsing

    @property
    def secure_access_web_proxy(self):
        """Gets the secure_access_web_proxy of this GatewayUpdateProducerAws.  # noqa: E501


        :return: The secure_access_web_proxy of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_web_proxy

    @secure_access_web_proxy.setter
    def secure_access_web_proxy(self, secure_access_web_proxy):
        """Sets the secure_access_web_proxy of this GatewayUpdateProducerAws.


        :param secure_access_web_proxy: The secure_access_web_proxy of this GatewayUpdateProducerAws.  # noqa: E501
        :type: bool
        """

        self._secure_access_web_proxy = secure_access_web_proxy

    @property
    def tags(self):
        """Gets the tags of this GatewayUpdateProducerAws.  # noqa: E501

        List of the tags attached to this secret  # noqa: E501

        :return: The tags of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this GatewayUpdateProducerAws.

        List of the tags attached to this secret  # noqa: E501

        :param tags: The tags of this GatewayUpdateProducerAws.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def target_name(self):
        """Gets the target_name of this GatewayUpdateProducerAws.  # noqa: E501

        Target name  # noqa: E501

        :return: The target_name of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this GatewayUpdateProducerAws.

        Target name  # noqa: E501

        :param target_name: The target_name of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._target_name = target_name

    @property
    def token(self):
        """Gets the token of this GatewayUpdateProducerAws.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayUpdateProducerAws.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayUpdateProducerAws.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayUpdateProducerAws.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def user_ttl(self):
        """Gets the user_ttl of this GatewayUpdateProducerAws.  # noqa: E501

        User TTL  # noqa: E501

        :return: The user_ttl of this GatewayUpdateProducerAws.  # noqa: E501
        :rtype: str
        """
        return self._user_ttl

    @user_ttl.setter
    def user_ttl(self, user_ttl):
        """Sets the user_ttl of this GatewayUpdateProducerAws.

        User TTL  # noqa: E501

        :param user_ttl: The user_ttl of this GatewayUpdateProducerAws.  # noqa: E501
        :type: str
        """

        self._user_ttl = user_ttl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayUpdateProducerAws):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayUpdateProducerAws):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class KMIPServer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'active': 'bool',
        'ca': 'list[int]',
        'certificate': 'list[int]',
        'certificate_issue_date': 'datetime',
        'certificate_ttl_in_seconds': 'int',
        'hostname': 'str',
        'root': 'str'
    }

    attribute_map = {
        'active': 'active',
        'ca': 'ca',
        'certificate': 'certificate',
        'certificate_issue_date': 'certificate_issue_date',
        'certificate_ttl_in_seconds': 'certificate_ttl_in_seconds',
        'hostname': 'hostname',
        'root': 'root'
    }

    def __init__(self, active=None, ca=None, certificate=None, certificate_issue_date=None, certificate_ttl_in_seconds=None, hostname=None, root=None, local_vars_configuration=None):  # noqa: E501
        """KMIPServer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._active = None
        self._ca = None
        self._certificate = None
        self._certificate_issue_date = None
        self._certificate_ttl_in_seconds = None
        self._hostname = None
        self._root = None
        self.discriminator = None

        if active is not None:
            self.active = active
        if ca is not None:
            self.ca = ca
        if certificate is not None:
            self.certificate = certificate
        if certificate_issue_date is not None:
            self.certificate_issue_date = certificate_issue_date
        if certificate_ttl_in_seconds is not None:
            self.certificate_ttl_in_seconds = certificate_ttl_in_seconds
        if hostname is not None:
            self.hostname = hostname
        if root is not None:
            self.root = root

    @property
    def active(self):
        """Gets the active of this KMIPServer.  # noqa: E501


        :return: The active of this KMIPServer.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this KMIPServer.


        :param active: The active of this KMIPServer.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def ca(self):
        """Gets the ca of this KMIPServer.  # noqa: E501


        :return: The ca of this KMIPServer.  # noqa: E501
        :rtype: list[int]
        """
        return self._ca

    @ca.setter
    def ca(self, ca):
        """Sets the ca of this KMIPServer.


        :param ca: The ca of this KMIPServer.  # noqa: E501
        :type: list[int]
        """

        self._ca = ca

    @property
    def certificate(self):
        """Gets the certificate of this KMIPServer.  # noqa: E501


        :return: The certificate of this KMIPServer.  # noqa: E501
        :rtype: list[int]
        """
        return self._certificate

    @certificate.setter
    def certificate(self, certificate):
        """Sets the certificate of this KMIPServer.


        :param certificate: The certificate of this KMIPServer.  # noqa: E501
        :type: list[int]
        """

        self._certificate = certificate

    @property
    def certificate_issue_date(self):
        """Gets the certificate_issue_date of this KMIPServer.  # noqa: E501


        :return: The certificate_issue_date of this KMIPServer.  # noqa: E501
        :rtype: datetime
        """
        return self._certificate_issue_date

    @certificate_issue_date.setter
    def certificate_issue_date(self, certificate_issue_date):
        """Sets the certificate_issue_date of this KMIPServer.


        :param certificate_issue_date: The certificate_issue_date of this KMIPServer.  # noqa: E501
        :type: datetime
        """

        self._certificate_issue_date = certificate_issue_date

    @property
    def certificate_ttl_in_seconds(self):
        """Gets the certificate_ttl_in_seconds of this KMIPServer.  # noqa: E501


        :return: The certificate_ttl_in_seconds of this KMIPServer.  # noqa: E501
        :rtype: int
        """
        return self._certificate_ttl_in_seconds

    @certificate_ttl_in_seconds.setter
    def certificate_ttl_in_seconds(self, certificate_ttl_in_seconds):
        """Sets the certificate_ttl_in_seconds of this KMIPServer.


        :param certificate_ttl_in_seconds: The certificate_ttl_in_seconds of this KMIPServer.  # noqa: E501
        :type: int
        """

        self._certificate_ttl_in_seconds = certificate_ttl_in_seconds

    @property
    def hostname(self):
        """Gets the hostname of this KMIPServer.  # noqa: E501


        :return: The hostname of this KMIPServer.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this KMIPServer.


        :param hostname: The hostname of this KMIPServer.  # noqa: E501
        :type: str
        """

        self._hostname = hostname

    @property
    def root(self):
        """Gets the root of this KMIPServer.  # noqa: E501


        :return: The root of this KMIPServer.  # noqa: E501
        :rtype: str
        """
        return self._root

    @root.setter
    def root(self, root):
        """Sets the root of this KMIPServer.


        :param root: The root of this KMIPServer.  # noqa: E501
        :type: str
        """

        self._root = root

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KMIPServer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KMIPServer):
            return True

        return self.to_dict() != other.to_dict()
